from setuptools import setup

setup(
    name="sergiu-presentation",
    version="0.1.2",
    author="Matei Sergiu-Răzvan",
    author_email="mateisergiu777@gmail.com",
    package_dir={"": "src/"},
    packages=["sergiu_presentation"],
    include_package_data=True,
    description="Demo library",
    long_description="This is just a demo library"
)
